@@ -19,11 +19,7 @@ pub mod set;
 pub type Error = Box<dyn ark_std::error::Error>;
 
 pub mod prelude {
-	pub use ark_bls12_381;
-	pub use ark_bn254;
 	pub use ark_crypto_primitives;
-	pub use ark_ed_on_bls12_381;
-	pub use ark_ed_on_bn254;
 	pub use ark_ff;
 	pub use ark_groth16;
 	pub use ark_marlin;
